A Pelican Blog - Alexis Métaireau

# This is a super article !

Some content here !

## This is a simple title

And here comes the cool stuff.

    >>> from ipdb import set_trace
    >>> set_trace()

→ And now try with some utf8 hell: ééé

# Other articles

1. # Oh yeah !

   ## Why not ?

   After all, why not ? It's pretty simple to do it, and it will allow me to write my blogposts in rst ! YEAH !

   read more

## social

- atom feed